% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/fit_mglm.R
\name{fit_mglm}
\alias{fit_mglm}
\title{Chaser and Reciprocal Likelihood algorithms}
\source{
Bonat, W. H. and Jorgensen, B. (2016) Multivariate
    covariance generalized linear models.
    Journal of Royal Statistical Society - Series C 65:649--675.

Bonat, W. H. (2018). Multiple Response Variables Regression
Models in R: The mcglm Package. Journal of Statistical Software, 84(4):1--30.
}
\usage{
fit_mglm(list_initial, list_link, list_variance,
         list_X, list_Z, list_offset, list_Ntrial, list_power_fixed,
         list_weights, y_vec, correct, max_iter, tol, method,
         tuning, verbose)
}
\arguments{
\item{list_initial}{a list of initial values for regression and
covariance parameters.}

\item{list_link}{a list specifying the link function names. \cr
Options are: \code{"logit"}, \code{"probit"}, \code{"cauchit"},
\code{"cloglog"}, \code{"loglog"}, \code{"identity"}, \code{"log"},
\code{"sqrt"}, \code{"1/mu^2"} and \code{"inverse"}. \cr
See \code{\link{mt_link_function}} for details.
Default \code{link = "identity"}.}

\item{list_variance}{a list specifying the variance function names.
Options are: \code{"constant"}, \code{"tweedie"},
\code{"poisson_tweedie"}, \code{"binomialP"} and \code{"binomialPQ"}.
See \code{\link{mt_variance_function}} for details.
Default \code{variance = "constant"}.}

\item{list_X}{a list of design matrices.
See \code{\link[stats]{model.matrix}} for details.}

\item{list_Z}{a list of knowm matrices to compose the matrix linear
predictor.}

\item{list_offset}{a list of offset values. Default NULL.}

\item{list_Ntrial}{a list of number of trials, useful only when
analysing binomial data. Default 1.}

\item{list_power_fixed}{a list of logicals indicating if the power
parameters should be estimated or not. Default \code{power_fixed = TRUE}.}

\item{list_weights}{Additional weights for the quasi-score function. (Default = NULL).}

\item{y_vec}{a vector of the stacked response variables.}

\item{correct}{a logical indicating if the algorithm will use the
correction term or not. Default \code{correct = FALSE}.}

\item{max_iter}{maximum number of iterations. Default \code{max_iter = 20}.}

\item{tol}{a numeric specyfing the tolerance. Default \code{tol = 1e-04}.}

\item{method}{a string specyfing the method used to fit the models
(\code{"chaser"} or \code{"rc"}). Default \code{method = "chaser"}.}

\item{tuning}{a numeric value in general close to zero for the rc
method and close to 1 for the chaser method. This argument control
the step-length. Default \code{tuning = 1}.}

\item{verbose}{a logical if TRUE print the values of the covariance
parameters used on each iteration. Default \code{verbose = FALSE}}
}
\value{
A list with estimated regression and covariance parameters.
Details about the estimation procedures as iterations, sensitivity,
variability are also provided. In general the users do not need to
use this function directly. The \code{\link{mglm4twin}} provides GLM
interface for fitting multivariate generalized linear models for twin data.
}
\description{
This function implements the two main algorithms used
for fitting multivariate generalized linear models to twin data, i.e.
The chaser and the reciprocal likelihood algorithms.
}
\seealso{
\code{mglm4twin}, \code{mt_matrix_linear_predictor},
 \code{mt_link_function} and \cr \code{mt_variance_function}.
}
\author{
Wagner Hugo Bonat, \email{wbonat@ufpr.br}
}
